@@ -29,11 +29,11 @@ def t():
   tear_down()
   return passed
 
-def f(t_0, Π_to_test, t_now=None):
+def f(t_0, _Pi_to_test, t_now=None):
   t_now = t_now or time()
 
   remove('./failed.pickle')
   return (
     True,
-    f"{success('PASS')} {1000*(t_now-t_0):0.2f} ms. Tested: {Π_to_test}"
+    f"{success('PASS')} {1000*(t_now-t_0):0.2f} ms. Tested: {_Pi_to_test}"
   )
\ No newline at end of file
